@@ -31,6 +31,10 @@ def torch_installed():
         return False
 
 
+def assert_torch_installed():
+    assert torch_installed(), "To use Hummingbird you need to install torch."
+
+
 def onnx_ml_tools_installed():
     """
     Checks that *ONNXMLTools* is available.
@@ -44,6 +48,12 @@ def onnx_ml_tools_installed():
         return False
 
 
+def assert_onnx_ml_tools_installed():
+    assert (
+        onnx_ml_tools_installed()
+    ), "ONNXMLTOOLS not installed. Please check https://github.com/onnx/onnxmltools for instructions."
+
+
 def onnx_runtime_installed():
     """
     Checks that *ONNX Runtime* is available.
@@ -56,6 +66,10 @@ def onnx_runtime_installed():
         return False
 
 
+def assert_onnx_runtime_installed():
+    assert onnx_runtime_installed()
+
+
 def sparkml_installed():
     """
     Checks that *Spark ML/PySpark* is available.
@@ -68,6 +82,10 @@ def sparkml_installed():
         return False
 
 
+def assert_sparkml_installed():
+    assert sparkml_installed()
+
+
 def sklearn_installed():
     """
     Checks that *Sklearn* is available.
@@ -80,6 +98,10 @@ def sklearn_installed():
         return False
 
 
+def assert_sklearn_installed():
+    assert sklearn_installed()
+
+
 def lightgbm_installed():
     """
     Checks that *LightGBM* is available.
@@ -92,6 +114,12 @@ def lightgbm_installed():
         return False
 
 
+def assert_lightgbm_installed():
+    assert (
+        lightgbm_installed()
+    ), "To convert LightGBM models you need to install LightGBM (or `pip install hummingbird-ml[extra]`)."
+
+
 def xgboost_installed():
     """
     Checks that *XGBoost* is available.
@@ -117,6 +145,12 @@ def xgboost_installed():
     return True
 
 
+def assert_xgboost_installed():
+    assert (
+        xgboost_installed()
+    ), "To convert XGBoost models you need to install XGBoost (or `pip install hummingbird-ml[extra]`)."
+
+
 def tvm_installed():
     """
     Checks that *TVM* is available.
@@ -128,6 +162,10 @@ def tvm_installed():
     return True
 
 
+def assert_tvm_installed():
+    assert tvm_installed()
+
+
 def pandas_installed():
     """
     Checks that *Pandas* is available.
@@ -139,6 +177,21 @@ def pandas_installed():
     return True
 
 
+def assert_pandas_installed():
+    assert pandas_installed()
+
+
+def prophet_installed():
+    """
+    Checks that *Prophet* is available.
+    """
+    try:
+        from prophet import Prophet
+    except ImportError:
+        return False
+    return True
+
+
 def is_pandas_dataframe(df):
     import pandas as pd
 
