@@ -15,9 +15,9 @@ from .operator_converters import constants
 from ._parse import parse_sklearn_api_model, parse_onnx_api_model, parse_sparkml_api_model
 from ._topology import convert as topology_converter
 from ._utils import (
-    torch_installed,
-    lightgbm_installed,
-    xgboost_installed,
+    assert_torch_installed,
+    assert_lightgbm_installed,
+    assert_xgboost_installed,
     pandas_installed,
     sparkml_installed,
     is_pandas_dataframe,
@@ -67,7 +67,7 @@ def _supported_backend_check_config(model, backend, extra_config):
     """
     Function used to check whether the specified backend and configuration pair is supported or not.
     """
-    assert torch_installed(), "To use Hummingbird you need to install torch."
+    assert_torch_installed()
     import onnx
     import torch
 
@@ -80,9 +80,14 @@ def _supported_backend_check_config(model, backend, extra_config):
     if (
         (backend == torch.jit.__name__ and not _is_onnx_model(model))
         or backend == tvm_backend
-        or (backend == onnx.__name__ and not _is_onnx_model(model))
+        or (backend == onnx.__name__ and not _is_onnx_model(model) or _is_onnx_model(model) and backend == torch.__name__)
     ) and constants.TEST_INPUT not in extra_config:
-        raise RuntimeError("Backend {} requires test inputs. Please pass some test input to the convert.".format(backend))
+        raise RuntimeError(
+            "Backend {} requires test inputs. \
+            Please pass some test input to the convert function.".format(
+                backend
+            )
+        )
 
 
 def _convert_sklearn(model, backend, test_input, device, extra_config={}):
@@ -91,7 +96,7 @@ def _convert_sklearn(model, backend, test_input, device, extra_config={}):
     The supported operators and backends can be found at `hummingbird.ml.supported`.
     """
     assert model is not None
-    assert torch_installed(), "To use Hummingbird you need to install torch."
+    assert_torch_installed()
 
     # Parse scikit-learn model as our internal data structure (i.e., Topology)
     # We modify the scikit learn model during translation.
@@ -108,9 +113,7 @@ def _convert_lightgbm(model, backend, test_input, device, extra_config={}):
     This function is used to generate a *backend* model from a given input [LightGBM] model.
     [LightGBM]: https://lightgbm.readthedocs.io/
     """
-    assert (
-        lightgbm_installed()
-    ), "To convert LightGBM models you need to install LightGBM (or `pip install hummingbird-ml[extra]`)."
+    assert_lightgbm_installed()
 
     return _convert_sklearn(model, backend, test_input, device, extra_config)
 
@@ -120,13 +123,14 @@ def _convert_xgboost(model, backend, test_input, device, extra_config={}):
     This function is used to generate a *backend* model from a given input [XGBoost] model.
     [XGBoost]: https://xgboost.readthedocs.io/
     """
-    assert (
-        xgboost_installed()
-    ), "To convert XGboost models you need to instal XGBoost (or `pip install hummingbird-ml[extra]`)."
+    assert_xgboost_installed()
 
     # XGBoostRegressor and Classifier have different APIs for extracting the number of features.
     # In the former case we need to infer them from the test_input.
-    if "_features_count" in dir(model):
+    booster = model.get_booster() if hasattr(model, "get_booster") else model
+    if hasattr(booster, "num_features"):
+        extra_config[constants.N_FEATURES] = booster.num_features()
+    elif "_features_count" in dir(model):
         extra_config[constants.N_FEATURES] = model._features_count
     elif test_input is not None:
         if type(test_input) is np.ndarray and len(test_input.shape) == 2:
@@ -151,7 +155,7 @@ def _convert_onnxml(model, backend, test_input, device, extra_config={}):
     The supported operators can be found at `hummingbird.ml.supported`.
     """
     assert model is not None
-    assert torch_installed(), "To use Hummingbird you need to install torch."
+    assert_torch_installed()
 
     import onnx
 
@@ -269,7 +273,7 @@ def _convert_sparkml(model, backend, test_input, device, extra_config={}):
     The supported operators and backends can be found at `hummingbird.ml.supported`.
     """
     assert model is not None
-    assert torch_installed(), "To use Hummingbird you need to install torch."
+    assert_torch_installed()
 
     # Parse Spark-ML model as our internal data structure (i.e., Topology)
     # We modify the Spark-ML model during translation.
